What is Kedro? — Kedro 0.17.6 documentation

# What is Kedro?

Kedro is an open-source Python framework for creating reproducible, maintainable and modular data science code. It borrows concepts from software engineering best-practice and applies them to machine-learning code; applied concepts include modularity, separation of concerns and versioning.

For the source code, take a look at the Kedro repository on Github.

## Learn how to use Kedro

In the next few chapters, you will learn how to install Kedro and set up your own production-ready data pipelines.

Once you are set up, we suggest working through our examples, including:

- A typical “Hello World” example, for an entry-level description of the main Kedro concepts

- An introduction to the project template using the Iris dataset

- A more detailed spaceflights tutorial to give you hands-on experience

We also recommend the frequently asked questions and the API reference documentation for additional information.

## Assumptions

We have designed the documentation and the spaceflights tutorial for anyone new to Kedro. The more knowledge of Python you have, the easier you will find the learning curve.

Note

There are a number of excellent online resources for learning Python, but you should choose those that reference Python 3, as Kedro is built for Python 3.6+. There are many curated lists of online resources, such as the official Python programming language website and this list of free programming books and tutorials.